Learn R Programming

metevalue (version 0.2.4)

evalue_buildin_var_fmt_nm: Build-in check file format function Perform the format check and data clean for the "metilene" or "biseq", "DMRfinder" or "methylKit" method correspondingly.

Description

Build-in check file format function Perform the format check and data clean for the "metilene" or "biseq", "DMRfinder" or "methylKit" method correspondingly.

Usage

evalue_buildin_var_fmt_nm(a, b, method = "metilene")

Value

list(a, b) which contains the cleaned data correspondingly

Arguments

a

data frame of the methylation rate

b

data frame of output data corresponding to the "method" option

method

"metilene" or "biseq", "DMRfinder" or "methylKit"

Examples

Run this code
# \donttest{
data("demo_metilene_out")
data("demo_metilene_input")
evalue_buildin_var_fmt_nm(demo_metilene_input,
                          demo_metilene_out, method="metilene")
# }

Run the code above in your browser using DataLab