evalue_buildin_var_fmt_nm: Build-in check file format function
Perform the format check and data clean for the "metilene" or "biseq", "DMRfinder" or "methylKit" method correspondingly.
Description
Build-in check file format function
Perform the format check and data clean for the "metilene" or "biseq", "DMRfinder" or "methylKit" method correspondingly.